==> 0.0.1.tar.gz: lib/services/data_service.dart <==
import 'package:ahai_pub_data/data/local_data.dart';
import 'package:ahai_pub_data/data/local_data1.dart';
import 'package:ahai_pub_data/model/ahai_about_us_model.dart';
import 'package:ahai_pub_data/model/ahai_card_horizontal_model.dart';
import 'package:ahai_pub_data/model/ahai_card_horizontal_with_popup_model.dart';
import 'package:ahai_pub_data/model/ahai_card_horizontal_with_sub_model.dart';
import 'package:ahai_pub_data/model/ahai_card_image_widget_model.dart';
import 'package:ahai_pub_data/model/ahai_card_vertical_top_bottom_content_model.dart';
import 'package:ahai_pub_data/model/ahai_map_details_model.dart';
import 'package:ahai_pub_data/utils/ahai_convertor.dart';

class DataServices {
  Future<List<AhaiCardHorizontalModel>> getVehicles() async {
    return AhaiConvertor.AhaiCardHorizontalFromMap(LocalData.vehicles);
  }

  Future<List<AhaiCardHorizontalModel>> getConsumables() async {
    return AhaiConvertor.AhaiCardHorizontalFromMap(LocalData.consumables);
  }

  Future<List<AhaiCardHorizontalWithPopupModel>> getSensitivity(
      String url) async {
    var localData = '';
    if (url.contains('device')) {
      localData = LocalData.ramSensitivity;
    } else {
      localData = LocalData.playerSensitivity;
    }
    return AhaiConvertor.AhaiCardHorizontalWithPopupFromMap(localData);
  }

  Future<List<AhaiCardImageWidgetModel>> getScreenLayouts() async {
    return AhaiConvertor.AhaiCardImageWidgetModelFromMap(
        LocalData.controlLayouts);
  }

  Future<List<AhaiCardVerticalTopBottomContentModel>> getCircleDetails() async {
    return AhaiConvertor.AhaiCardVerticalTopBottomContentFromMap(
        LocalData.circles);
  }

  Future<List<String>> getMaps() async {
    var result = <String>[];
    var tempResult = AhaiConvertor.AhaiDropdownMapModelFromMap(LocalData.maps);
    if (tempResult.isNotEmpty) {
      for (var element in tempResult) {
        result.add(element.name);
      }
    }
    return result;
  }

  Future<List<AhaiAboutUsModel>> getAboutUs() async {
    return AhaiConvertor.AhaiAboutUsModelFromMap(LocalData.about);
  }

  Future<List<AhaiMapDetailsModel>> getMapsDetails() async {
    return AhaiConvertor.AhaiMapDetailsModelFromMap(LocalData.mapDetails);
  }

  Future<List<AhaiCardHorizontalWithSubModel>> getDamagesDetails() async {
    return AhaiConvertor.AhaiCardHorizontalWithSubFromMap(
      LocalData1.items1,
    );
  }
}

==> 0.0.2.tar.gz: lib/services/data_service.dart <==
import 'package:ahai_pub_data/data/local_data.dart';
import 'package:ahai_pub_data/data/local_data1.dart';
import 'package:ahai_pub_data/model/ahai_about_us_model.dart';
import 'package:ahai_pub_data/model/ahai_card_horizontal_model.dart';
import 'package:ahai_pub_data/model/ahai_card_horizontal_with_popup_model.dart';
import 'package:ahai_pub_data/model/ahai_card_horizontal_with_sub_model.dart';
import 'package:ahai_pub_data/model/ahai_card_image_widget_model.dart';
import 'package:ahai_pub_data/model/ahai_card_vertical_top_bottom_content_model.dart';
import 'package:ahai_pub_data/model/ahai_map_details_model.dart';
import 'package:ahai_pub_data/utils/ahai_convertor.dart';

class DataServices {
  static Future<List<AhaiCardHorizontalModel>> getVehicles() async {
    return AhaiConvertor.AhaiCardHorizontalFromMap(LocalData.vehicles);
  }

  static Future<List<AhaiCardHorizontalModel>> getConsumables() async {
    return AhaiConvertor.AhaiCardHorizontalFromMap(LocalData.consumables);
  }

  static Future<List<AhaiCardHorizontalWithPopupModel>> getSensitivity(
      String url) async {
    var localData = '';
    if (url.contains('device')) {
      localData = LocalData.ramSensitivity;
    } else {
      localData = LocalData.playerSensitivity;
    }
    return AhaiConvertor.AhaiCardHorizontalWithPopupFromMap(localData);
  }

  static Future<List<AhaiCardImageWidgetModel>> getScreenLayouts() async {
    return AhaiConvertor.AhaiCardImageWidgetModelFromMap(
        LocalData.controlLayouts);
  }

  static Future<List<AhaiCardVerticalTopBottomContentModel>>
      getCircleDetails() async {
    return AhaiConvertor.AhaiCardVerticalTopBottomContentFromMap(
        LocalData.circles);
  }

  static Future<List<String>> getMaps() async {
    var result = <String>[];
    var tempResult = AhaiConvertor.AhaiDropdownMapModelFromMap(LocalData.maps);
    if (tempResult.isNotEmpty) {
      for (var element in tempResult) {
        result.add(element.name);
      }
    }
    return result;
  }

  static Future<List<AhaiAboutUsModel>> getAboutUs() async {
    return AhaiConvertor.AhaiAboutUsModelFromMap(LocalData.about);
  }

  static Future<List<AhaiMapDetailsModel>> getMapsDetails() async {
    return AhaiConvertor.AhaiMapDetailsModelFromMap(LocalData.mapDetails);
  }

  static Future<List<AhaiCardHorizontalWithSubModel>>
      getDamagesDetails() async {
    return AhaiConvertor.AhaiCardHorizontalWithSubFromMap(
      LocalData1.items1,
    );
  }
}
